#version 330
#extension GL_ARB_separate_shader_objects : enable





layout(location = 0) smooth in vec2 _fin_fragTexCoord;

struct SFragmentInput
{
	vec2 fragTexCoord;
	bool IsFrontFace;
};

layout(location = 0) out vec4 _fout_outColor;

struct SFragmentOutput
{
	vec4 outColor;
};

 uniform sampler2D Texture;

layout( std140) uniform UDepthInfo
{
	float DepthNear;
	float DepthFar;
} DepthInfo;

vec3 UnpackNormalSpheremap(vec2 normal)
{
	vec4 nn = vec4(normal * 2.0 - 1.0, 1., -1.);
	float l = dot(nn.xyz, -nn.xyw);
	nn.z = l;
	nn.xy *= sqrt(l);
	return nn.xyz + vec3(0.5, 0.5, 0.);
}

void FragmentMain( in SFragmentInput  fInput,  out SFragmentOutput  fOutput  )
{



	vec2 uv = fInput.fragTexCoord;


	fOutput.outColor =  texture(Texture, uv) ;




	float z = fOutput.outColor.r;
	float zNear =  DepthInfo.DepthNear ;
	float zFar =  DepthInfo.DepthFar ;
	z = (2.0 * zNear) / (zFar + zNear - z * (zFar - zNear));
	fOutput.outColor = vec4(z, z, z, z);
}


void main()
{
	SFragmentInput fInput;
	SFragmentOutput fOutput;

	fInput.fragTexCoord = _fin_fragTexCoord;
	fInput.IsFrontFace = gl_FrontFacing;
	FragmentMain(fInput, fOutput);
	_fout_outColor = fOutput.outColor;
}
